from distutils.core import setup

setup(
    name        ='nnnester',
    version     ='1.1.0',
    py_modules  =['nnnester'],
    author      ='owencx',
    author_email='cx1410431042@gmail.com',
    description ='A simple printer of nester lists',
    )
